@@ -1,4 +1,4 @@
-/* $Id: cdb_init.c,v 1.9 2003/11/03 21:42:20 mjt Exp $
+/* $Id: cdb_init.c,v 1.11 2006/09/03 10:17:45 mjt Exp $
  * cdb_init, cdb_free and cdb_read routines
  *
  * This file is a part of tinycdb package by Michael Tokarev, mjt@corpit.ru.
@@ -10,6 +10,9 @@
 # include <windows.h>
 #else
 # include <sys/mman.h>
+# ifndef MAP_FAILED
+#  define MAP_FAILED ((void*)-1)
+# endif
 #endif
 #include <sys/stat.h>
 #include "cdb_int.h"
@@ -34,14 +37,17 @@ cdb_init(struct cdb *cdbp, int fd)
   /* memory-map file */
 #ifdef _WIN32
   hFile = (HANDLE) _get_osfhandle(fd);
-  if(hFile == (HANDLE) -1) return -1;
+  if (hFile == (HANDLE) -1)
+    return -1;
   hMapping = CreateFileMapping(hFile, NULL, PAGE_READONLY, 0, 0, NULL);
-  if (!hMapping) return -1;
-  mem = MapViewOfFile(hMapping, FILE_MAP_READ, 0, 0, 0);
-  if (!mem) return -1;
+  if (!hMapping)
+    return -1;
+  mem = (unsigned char *)MapViewOfFile(hMapping, FILE_MAP_READ, 0, 0, 0);
+  if (!mem)
+    return -1;
 #else
-  if ((mem = mmap(NULL, fsize, PROT_READ, MAP_SHARED, fd, 0)) ==
-      (unsigned char *)-1)
+  mem = (unsigned char*)mmap(NULL, fsize, PROT_READ, MAP_SHARED, fd, 0);
+  if (mem == MAP_FAILED)
     return -1;
 #endif /* _WIN32 */
 
