@@ -1,4 +1,4 @@
-/* $Id: cdb_seek.c,v 1.6 2003/11/03 16:42:41 mjt Exp $
+/* $Id: cdb_seek.c,v 1.7 2006/09/03 09:51:25 mjt Exp $
  * old interface for reading cdb file
  *
  * This file is a part of tinycdb package by Michael Tokarev, mjt@corpit.ru.
@@ -75,7 +75,7 @@ cdb_seek(int fd, const void *key, unsigned klen, unsigned *dlenp)
 	/* read the key from file and compare with wanted */
 	unsigned l = klen, c;
 	const char *k = (const char*)key;
-	if (*dlenp)
+	if (dlenp)
 	  *dlenp = cdb_unpack(rbuf + 4); /* save value length */
 	for(;;) {
 	  if (!l) /* the whole key read and matches, return */
